@@ -22,9 +22,10 @@ map <- function(x, range = c(0,1), from.range=NA) {
     if(any(is.na(from.range))) from.range <- range(x, na.rm=TRUE)
     
     ## check if all values are the same
-    if(!diff(from.range)) return(
-	    matrix(mean(range), ncol=ncol(x), nrow=nrow(x), 
-		    dimnames = dimnames(x)))
+    if(!diff(from.range)) {
+	x[] <- mean(range) 
+	return(x)
+    }
     
     ## map to [0,1]
     x <- (x-from.range[1])
